@@ -25,9 +25,10 @@
 #include "fileTree.h"
 #include "localLister.h"
 
-#include <KDebug>
-
-#include <QtGui/QApplication>
+#include <QGuiApplication>
+#include <QCursor>
+#include <QDir>
+#include <QStringBuilder>
 
 namespace Filelight
 {
@@ -48,7 +49,7 @@ ScanManager::ScanManager(QObject *parent)
 ScanManager::~ScanManager()
 {
     if (m_thread) {
-        kDebug() << "Attempting to abort scan operation..." << endl;
+        qDebug() << "Attempting to abort scan operation..." << endl;
         m_abort = true;
         m_thread->wait();
     }
@@ -63,35 +64,36 @@ bool ScanManager::running() const
     return m_thread && m_thread->isRunning();
 }
 
-bool ScanManager::start(const KUrl &url)
+bool ScanManager::start(const QUrl &url)
 {
     QMutexLocker locker(&m_mutex); // The m_mutex gets released once locker is destroyed (goes out of scope).
 
     //url is guaranteed clean and safe
 
-    kDebug() << "Scan requested for: " << url.prettyUrl() << endl;
+    qDebug() << "Scan requested for: " << url << endl;
 
     if (running()) {
-        kWarning() << "Tried to launch two concurrent scans, aborting old one...";
+        qWarning() << "Tried to launch two concurrent scans, aborting old one...";
         abort();
     }
 
     m_files = 0;
     m_abort = false;
 
-    if (url.protocol() == QLatin1String( "file" ))
-    {
-        const QString path = url.path(KUrl::AddTrailingSlash);
+    if (url.isLocalFile()) {
+        QString path = url.toLocalFile();
+
+        if (!path.endsWith(QDir::separator())) path += QDir::separator();
 
         Chain<Folder> *trees = new Chain<Folder>;
 
         /* CHECK CACHE
-        *   user wants: /usr/local/
-        *   cached:     /usr/
-        *
-        *   user wants: /usr/
-        *   cached:     /usr/local/, /usr/include/
-        */
+         *   user wants: /usr/local/
+         *   cached:     /usr/
+         *
+         *   user wants: /usr/
+         *   cached:     /usr/local/, /usr/include/
+         */
 
         for (Iterator<Folder> it = m_cache->iterator(); it != m_cache->end(); ++it)
         {
@@ -101,9 +103,13 @@ bool ScanManager::start(const KUrl &url)
             {
                 //find a pointer to the requested branch
 
-                kDebug() << "Cache-(a)hit: " << cachePath << endl;
+                qDebug() << "Cache-(a)hit: " << cachePath << endl;
 
+#if QT_VERSION >= 0x050400
+                QVector<QStringRef> split = path.midRef(cachePath.length()).split(QLatin1Char( '/' ));
+#else
                 QStringList split = path.mid(cachePath.length()).split(QLatin1Char( '/' ));
+#endif
                 Folder *d = *it;
                 Iterator<File> jt;
 
@@ -112,10 +118,16 @@ bool ScanManager::start(const KUrl &url)
                     jt = d->iterator();
 
                     const Link<File> *end = d->end();
+#if QT_VERSION >= 0x050400
+                    if (split.first().isEmpty()) //found the dir
+                        break;
+                    QString s = split.first() % QLatin1Char( '/' );
+#else
                     QString s = split.first();
                     if (s.isEmpty()) //found the dir
                         break;
                     s += QLatin1Char( '/' );
+#endif
 
                     for (d = 0; jt != end; ++jt)
                         if (s == (*jt)->name())
@@ -132,7 +144,7 @@ bool ScanManager::start(const KUrl &url)
                     delete trees;
 
                     //we found a completed tree, thus no need to scan
-                    kDebug() << "Found cache-handle, generating map.." << endl;
+                    qDebug() << "Found cache-handle, generating map.." << endl;
 
                     emit branchCacheHit(d);
 
@@ -141,20 +153,19 @@ bool ScanManager::start(const KUrl &url)
                 else
                 {
                     //something went wrong, we couldn't find the folder we were expecting
-                    kError() << "Didn't find " << path << " in the cache!\n";
+                    qWarning() << "Didn't find " << path << " in the cache!\n";
                     delete it.remove(); //safest to get rid of it
                     break; //do a full scan
                 }
             }
             else if (cachePath.startsWith(path)) //then part of the requested tree is already scanned
             {
-                kDebug() << "Cache-(b)hit: " << cachePath << endl;
+                qDebug() << "Cache-(b)hit: " << cachePath << endl;
                 it.transferTo(*trees);
             }
         }
 
-        m_url.setPath(path); //FIXME stop switching between paths and KURLs all the time
-        QApplication::setOverrideCursor(Qt::BusyCursor);
+        QGuiApplication::changeOverrideCursor(QCursor(Qt::BusyCursor));
         //starts listing by itself
         m_thread = new Filelight::LocalLister(path, trees, this);
         connect(m_thread, SIGNAL(branchCompleted(Folder*,bool)), this, SLOT(cacheTree(Folder*,bool)), Qt::QueuedConnection);
@@ -163,8 +174,7 @@ bool ScanManager::start(const KUrl &url)
         return true;
     }
 
-    m_url = url;
-    QApplication::setOverrideCursor(Qt::BusyCursor);
+    QGuiApplication::changeOverrideCursor(QCursor(Qt::BusyCursor));
     //will start listing straight away
     Filelight::RemoteLister *remoteLister = new Filelight::RemoteLister(url, (QWidget*)parent(), this);
     connect(remoteLister, SIGNAL(branchCompleted(Folder*,bool)), this, SLOT(cacheTree(Folder*,bool)), Qt::QueuedConnection);
@@ -203,9 +213,9 @@ ScanManager::cacheTree(Folder *tree, bool finished)
     QMutexLocker locker(&m_mutex); // This gets released once it is destroyed.
 
     if (m_thread) {
-        kDebug() << "Waiting for thread to terminate ...";
+        qDebug() << "Waiting for thread to terminate ...";
         m_thread->wait();
-        kDebug() << "Thread terminated!";
+        qDebug() << "Thread terminated!";
         delete m_thread; //note the lister deletes itself
         m_thread = 0;
     }
@@ -215,24 +225,24 @@ ScanManager::cacheTree(Folder *tree, bool finished)
     if (tree) {
         //we don't cache foreign stuff
         //we don't recache stuff (thus only type 1000 events)
-        if (m_url.protocol() == QLatin1String( "file" ) && finished)
+        if (finished)
             //TODO sanity check the cache
             m_cache->append(tree);
     }
     else //scan failed
         m_cache->empty(); //FIXME this is safe but annoying
 
-    QApplication::restoreOverrideCursor();
+    QGuiApplication::restoreOverrideCursor();
 }
 
 void
 ScanManager::foundCached(Folder *tree)
 {
     emit completed(tree);
-    QApplication::restoreOverrideCursor();
+    QGuiApplication::restoreOverrideCursor();
 }
 
 
 }
 
-#include "scan.moc"
+
